<?php
defined('IMAGEMAGICKGPS_PATH')or die('Hacking attempt!');

/*
 * There is two ways to use class methods as event handlers:
 *
 * >  add_event_handler('blockmanager_apply', array('SkeletonMenu', 'blockmanager_apply'));
 *      in this case the method 'blockmanager_apply' must be a static method of the class 'SkeletonMenu'
 *
 * >  $myObj = new SkeletonMenu();
 * >  add_event_handler('blockmanager_apply', array(&$myObj, 'blockmanager_apply'));
 *      in this case the method 'blockmanager_apply' must be a public method of the object '$myObj'
 */

class ImageMagickGPS
{
	/**
	 * plugin initialization
	 *   - check for upgrades
	 *   - unserialize configuration
	 *   - load language
	 */
	static function on_init()
	{
		global $conf;

		// load plugin language file
		load_language('plugin.lang', IMAGEMAGICKGPS_PATH);

		// prepare plugin configuration
		$conf['imagemagick_gps'] = safe_unserialize($conf['imagemagick_gps']);
	}

	static function on_format_exif_data($exif, $filepath, $map)
	{
		global $conf;

		if ($conf['imagemagick_gps']['addAlwaysGpsData'] == false)
		{
			/* Check for existing GPS position data */
			$gpsExif = array_intersect_key($exif, array_flip(array('GPSLatitudeRef', 'GPSLatitude', 'GPSLongitudeRef', 'GPSLongitude')));
			if (count($gpsExif) == 4)
			{
				return $exif;
			}
		}

		/* Create the object */
		$im = new imagick($filepath);

		/* Get the EXIF information */
		$gpsSearch = "";
		if ($conf['imagemagick_gps']['addOnlyPosition'])
		{
			$gpsSearch = "exif:GPSL*";
		}
		else
		{
			$gpsSearch = "exif:GPS*";
		}
		$exifGps = $im->getImageProperties($gpsSearch);

		if (!empty($exifGps))
		{
			$addSectionGps = true;
			$sections = '';
			if (isset($exif['SectionsFound']))
			{
				$sections = $exif['SectionsFound'];
				if (strpos($sections, 'GPS') == false)
				{
					$sections = $sections.', ';
				}
			}
			if ($addSectionGps)
			{
				$exif['SectionsFound'] = $sections.'GPS';
			}
		}

		/* Get GPS Keys */
		$exifGpsKeys = array_keys($exifGps);

		$search = "exif:";
		$replace = "";

		foreach($exifGpsKeys as $gpsKey)
		{
			/* replace exif: from key */
			$gpsKeyStripped = str_replace($search, $replace, $gpsKey);

			/* skip some keys, probably not used in piwigo */
			switch ($gpsKeyStripped)
			{
			case "GPSAreaInformation":
			case "GPSProcessingMethod":
				continue 2;
			}

			$gpsValue = $exifGps[$gpsKey];

			$gpsValueSplitted = explode(",", $gpsValue, 4);

			$splittedCount = count($gpsValueSplitted);

			switch ($splittedCount)
			{
			case 3:
				/* add position values as array to exif, gpstime is also splitted, probably not used */
				$exif[$gpsKeyStripped] = $gpsValueSplitted;
				break;
			default:
				/* add gps value to exif */
				$exif[$gpsKeyStripped] = $gpsValue;
			}

		}

		return $exif;
	}

}